@@ -255,7 +255,7 @@ class Document(object):
         """ iter document instance properties
         """
 
-        all_properties = self._properties
+        all_properties = self._properties.copy()
         if self._dynamic_properties is not None:
             all_properties.update(self._dynamic_properties)
 
